Index: src/gpu/SkGpuDevice.cpp |
diff --git a/src/gpu/SkGpuDevice.cpp b/src/gpu/SkGpuDevice.cpp |
index 64439a1882ef06f7f88b8655837130ebe10488b2..f2bd025a0f6e5d9bc29777213420914d2549a783 100644 |
--- a/src/gpu/SkGpuDevice.cpp |
+++ b/src/gpu/SkGpuDevice.cpp |
@@ -1854,14 +1854,14 @@ void SkGpuDevice::EXPERIMENTAL_optimize(const SkPicture* picture) { |
return; |
} |
- SkPicture::AccelData::Key key = GPUAccelData::ComputeAccelDataKey(); |
+ SkPicture::AccelData::Key key = GrAccelData::ComputeAccelDataKey(); |
const SkPicture::AccelData* existing = picture->EXPERIMENTAL_getAccelData(key); |
if (NULL != existing) { |
return; |
} |
- SkAutoTUnref<GPUAccelData> data(SkNEW_ARGS(GPUAccelData, (key))); |
+ SkAutoTUnref<GrAccelData> data(SkNEW_ARGS(GrAccelData, (key))); |
picture->EXPERIMENTAL_addAccelData(data); |
@@ -1885,14 +1885,14 @@ bool SkGpuDevice::EXPERIMENTAL_drawPicture(SkCanvas* mainCanvas, const SkPicture |
fContext->getLayerCache()->processDeletedPictures(); |
- SkPicture::AccelData::Key key = GPUAccelData::ComputeAccelDataKey(); |
+ SkPicture::AccelData::Key key = GrAccelData::ComputeAccelDataKey(); |
const SkPicture::AccelData* data = picture->EXPERIMENTAL_getAccelData(key); |
if (NULL == data) { |
return false; |
} |
- const GPUAccelData *gpuData = static_cast<const GPUAccelData*>(data); |
+ const GrAccelData *gpuData = static_cast<const GrAccelData*>(data); |
if (0 == gpuData->numSaveLayers()) { |
return false; |
@@ -1925,11 +1925,11 @@ bool SkGpuDevice::EXPERIMENTAL_drawPicture(SkCanvas* mainCanvas, const SkPicture |
for (int i = 0; i < ops->numOps(); ++i) { |
uint32_t offset = ops->offset(i); |
// For now we're saving all the layers in the GPUAccelData so they |
// can be nested. Additionally, the nested layers appear before |
// their parent in the list. |
for (int j = 0 ; j < gpuData->numSaveLayers(); ++j) { |
- const GPUAccelData::SaveLayerInfo& info = gpuData->saveLayerInfo(j); |
+ const GrAccelData::SaveLayerInfo& info = gpuData->saveLayerInfo(j); |
if (pullForward[j]) { |
continue; // already pulling forward |
@@ -1955,7 +1955,7 @@ bool SkGpuDevice::EXPERIMENTAL_drawPicture(SkCanvas* mainCanvas, const SkPicture |
// In this case there is no BBH associated with the picture. Pre-render |
// all the layers that intersect the drawn region |
for (int j = 0; j < gpuData->numSaveLayers(); ++j) { |
- const GPUAccelData::SaveLayerInfo& info = gpuData->saveLayerInfo(j); |
+ const GrAccelData::SaveLayerInfo& info = gpuData->saveLayerInfo(j); |
SkIRect layerRect = SkIRect::MakeXYWH(info.fOffset.fX, |
info.fOffset.fY, |
@@ -1987,7 +1987,7 @@ bool SkGpuDevice::EXPERIMENTAL_drawPicture(SkCanvas* mainCanvas, const SkPicture |
// Generate the layer and/or ensure it is locked |
for (int i = 0; i < gpuData->numSaveLayers(); ++i) { |
if (pullForward[i]) { |
- const GPUAccelData::SaveLayerInfo& info = gpuData->saveLayerInfo(i); |
+ const GrAccelData::SaveLayerInfo& info = gpuData->saveLayerInfo(i); |
GrCachedLayer* layer = fContext->getLayerCache()->findLayerOrCreate(picture->uniqueID(), |
info.fSaveLayerOpID, |
@@ -2125,7 +2125,7 @@ bool SkGpuDevice::EXPERIMENTAL_drawPicture(SkCanvas* mainCanvas, const SkPicture |
// unlock the layers |
for (int i = 0; i < gpuData->numSaveLayers(); ++i) { |
- const GPUAccelData::SaveLayerInfo& info = gpuData->saveLayerInfo(i); |
+ const GrAccelData::SaveLayerInfo& info = gpuData->saveLayerInfo(i); |
GrCachedLayer* layer = fContext->getLayerCache()->findLayer(picture->uniqueID(), |
info.fSaveLayerOpID, |
@@ -1925,11 +1925,11 @@ bool SkGpuDevice::EXPERIMENTAL_drawPicture(SkCanvas* mainCanvas, const SkPicture |
for (int i = 0; i < ops->numOps(); ++i) { |
uint32_t offset = ops->offset(i); |
- // For now we're saving all the layers in the GPUAccelData so they |
+ // For now we're saving all the layers in the GrAccelData so they |
// can be nested. Additionally, the nested layers appear before |
// their parent in the list. |